@@ -42,8 +42,8 @@ closure TYPEN:rtype STT_DECL:params {:instmt @stmt
 
 format MT:name PARAM*:params STR:format ;   @stmt  @token @new @name @cmpl
 decl TYPEN:type VARN:name expr:value @stmt @name
-return EXPR*:values ;  @stmt  @token @new @cmpl
-mapmap CLASSTN*:paths[] ;   @stmt   @token @new 
+return EXPR*:values   @stmt  @token @new @cmpl
+mapmap CLASSTN*:paths[]   @stmt   @token @new 
 
 weave ANY:aspect CMETHODN:method @stmt @token @new
 aspect TYPEN:type cmethod.. CLASSN:class METHODN:method STT_DECL:params {:instmt  @stmt @token @new
@@ -65,10 +65,12 @@ try {:trycase STT_CATCH:catch {:finally   @stmt  @token @new
 catch EXPTN:type VARN:name {:catch   @token @stmt
 finally @token
 throw expr:expt ;   @stmt  @token @new
-err ANY:msg ;   @stmt @cmpl
+err ANY:msg     @stmt @cmpl
 
-let  VARN:lvalue expr:rvalue     @stmt  @name @cmpl
+let      VARN:lvalue expr:rvalue     @stmt  @name @cmpl  @expr
+#letexpr  VARN:lvalue expr:rvalue     @stmt  @name @cmpl  @expr
 letmulti VARN*:names[]               @stmt    
+
 #next expr:value                  @stmt  @expr
 #prev expr:value                  @stmt  @expr
 
@@ -79,8 +81,6 @@ letmulti VARN*:names[]               @stmt
 @expr pcall   METHODN:method expr:base pcall.. expr*:args[] @stmt
 @expr mt      MT:mt expr:target expr:option @stmt  @cmpl
 @expr op      expr:first expr:second expr*:args[] @stmt  @cmpl
-#@expr typeof  expr:value  @stmt @cmpl
-#@expr default expr:value  @stmt @cmpl
 
 @expr trinary expr:bool expr:tvalue expr:fvalue @stmt  @cmpl
 @expr alt     expr*:bools[]  @stmt   @cmpl
@@ -597,7 +597,7 @@ def write_stmt_add(f, token):
 \t\ttc->c += 1;
 \t}
 \telse {
-\t\tknh_Stmt_perror(ctx, o, tc, KMSG_T%s);
+\t\tknh_Stmt_tokens_perror(ctx, o, tc, KMSG_T%s);
 \t}
 }
 ''' % (func, token, token))
