@@ -369,7 +369,7 @@ void knh_oarray_free(Ctx *ctx, knh_Object_t **a)
 	}
 	else {
 		knh_oarray_t *h = ((knh_oarray_t*)a) - 1;
-		int i;
+		size_t i;
 		for(i = 0; i < h->capacity; i++) {
 			knh_Object_RCdec(a[i]);
 			if(knh_Object_isRC0(a[i])) {
