@@ -204,7 +204,7 @@ Term *knh_StmtPARAMS_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns,
 {
 	KNH_ASSERT(IS_Method(mtd));
 
-	int i, size = DP(stmt)->size;
+	size_t i, size = DP(stmt)->size;
 	knh_class_t self_cid = TYPE_UNMASK_NN(btype);
 	knh_type_t rtype = knh_pmztype_totype(ctx, knh_Method_rtype(mtd), self_cid);
 	if(TYPE_ISNULLABLE(btype) && !knh_Method_isNullBase(mtd)) {
@@ -214,7 +214,7 @@ Term *knh_StmtPARAMS_typing(Ctx *ctx, Stmt *stmt, Compiler *cpr, NameSpace *ns,
 
 	for(i = 0; i < knh_Method_psize(mtd); i++) {
 		knh_type_t reqt = knh_pmztype_totype(ctx, knh_Method_ptype(mtd, i), self_cid);
-		int n = i + 2;
+		size_t n = i + 2;
 		//DEBUG3("reqt[%d]=%d,%s%s", n, reqt, TYPEQN(reqt));
 		if(n < size) {
 			knh_Stmt_terms_typing(ctx, stmt, n, cpr, ns, TYPE_UNMASK_NN(reqt));
