@@ -351,7 +351,7 @@ Token *new_TokenVARN(Ctx *ctx, Token *tk, knh_bytes_t name)
 static
 int knh_bytes_isCLASSN(knh_bytes_t t)
 {
-	knh_index_t i;
+	size_t i;
 	if(!isupper(t.buf[0])) return 0;
 	for(i = 1; i < t.len; i++) {
 		if(!isalnum(t.buf[i])) return 0;
@@ -375,7 +375,7 @@ int knh_bytes_isCONSTN(knh_bytes_t t)
 	knh_index_t loc = knh_bytes_rindex(t, '.');
 	if(loc == -1 || !knh_bytes_isCLASSN(knh_bytes_first(t, loc))) return 0;
 	t = knh_bytes_last(t,loc+1);
-	knh_index_t i;
+	size_t i;
 	if(!isupper(t.buf[0])) return 0;
 	for(i = 1; i < t.len; i++) {
 		if(!isupper(t.buf[i]) && !isdigit(t.buf[i]) && t.buf[i] != '_') return 0;
