@@ -654,7 +654,7 @@ Token *new_Token__name(Ctx *ctx, knh_flag_t flag, knh_fileid_t fileid, knh_line_
 {
 	char name[KONOHA_NAME_BUFSIZ], *p = name;
 	knh_token_t tt = TT_NAME;
-	int i = 0;
+	size_t i = 0;
 	if(t.buf[0] == '.' && islower(t.buf[1])) {   /* .name   => name */
 		flag |= KNH_FLAG_TKF_TOPDOT;
 		t.buf++; t.len--;
@@ -952,7 +952,7 @@ void knh_Token_retokens(Ctx *ctx, Token *o)
 {
 	Array *a = (Array*)DP(o)->data;
 	if(IS_Array(a)) {
-		int i;
+		size_t i;
 		for(i = 0; i < knh_Array_size(a) - 1; i++) {
 			Token *tk = (Token*)knh_Array_n(a, i);
 			if(SP(tk)->tt == TT_TYPEN) {
