@@ -55,6 +55,9 @@ KNHAPI(size_t) knh_stat_usedMemorySize(void)
 
 INLINE void *knh_malloc(Ctx *ctx, size_t size)
 {
+#ifdef KONOHA_OS__TB
+	if(size == 0) size=4;
+#endif
 	void *block = malloc(size);
 	if (block == NULL) {
 		KNH_EXIT("OutOfMemory!!: %d bytes used", (int)knh_statUsedMemorySize);
@@ -1082,7 +1085,7 @@ void knh_tObject_traverse(Ctx *ctx, f_traverse ftr)
 	knh_tClass_traverse(ctx, ftr);
 
 	if(IS_SWEEP(ftr)) {
-		int i;
+		size_t i;
 		for(i = 0; i < knh_tObjectListSize; i++) {
 			knh_tObject_free(knh_tObjectList[i]);
 			knh_tObjectList[i] = NULL;
